﻿#pragma TextEncoding = "UTF-8"
#pragma rtGlobals=3
#pragma version=1
#pragma hide=1

#pragma ModuleName = LaTeX2PICT

Static StrConstant theFileName = "LaTeX2PICT"

// convert a LaTeX string to a PICT
Function/S ltxs2p(string lstr, [variable mmode])

	string pname	
	if (ParamIsDefault(mmode))
		mmode=1
	endif
	pname = LaTeX2PICT(lstr, mmode)
	return pname
end

// convert a LaTeX notebook to a PICT
Function/S ltxn2p(string ntbk)
	
	string pname	
	Notebook $ntbk, selection={startOfFile, endofFile}
	GetSelection notebook, $ntbk, 2
	pname = LaTeX2PICT(S_selection, 0, fulldoc=1)
	return pname
end

// convert a LaTeX string to a PICT
// provides additional levels of control
Function/S LaTeX2PICT(string LTXstr, variable mmode, [variable fsize, variable fulldoc, variable prterr, string iname, string xpreamble])
	
	if (ParamIsDefault(fsize))
		fsize = 12
	endif
	
	if (ParamIsDefault(iname))
		sprintf iname, "LaTeXPICT%3.0f", abs(enoise(100))
	endif
	iname = CleanUpName(iname,0)
	
	if (ParamIsDefault(prterr))
		prterr = 0
	endif
	
	if (ParamIsDefault(fulldoc))
		fulldoc = 0
	endif
	
	if (ParamIsDefault(xpreamble))
		xpreamble = ""
	endif
	
	// math mode
	if (mmode)
		sprintf LTXstr, "$%s$", LTXstr
	endif
	
	// encode the LaTeX string
	string thePreamble, theLaTeX
	if (!fulldoc)
		if (fsize==0)
			sprintf thePreamble, "\documentclass[class=scrreport,border=1pt]{standalone}\r"
		else
			sprintf thePreamble, "\documentclass[%dpt,class=scrreprt,border=1pt]{standalone}\r",fsize
		endif
		sprintf theLaTeX, "%s%s\begin{document}\r%s\r\end{document}", thePreamble, xPreamble, LTXstr
	else
		theLaTeX = LTXstr
	endif
	
	string/g theLaTeXSource = theLaTeX
	
	// set the folders
	string theTempFolder = SpecialDirPath("Temporary",0,0,0)
	string theTempFolderU =  SpecialDirPath("Temporary",0,1,0)
	string theTempFile

	// define the files
	string theTeXFile = theFileName + ".tex"
	string theDVIFile = theFileName + ".dvi"
	string thePDFFile = theFileName + ".pdf"
	string theEPSFile = theFileName + ".eps"
	
	// open and write to the tex file	
	NewPath/O/Q LaTeX2PICT theTempFolder
	
	// generate the notebook and save it
	KillWindow/Z LaTeX2PICTNtbk
	NewNotebook/F=0/K=3/N=LaTeX2PICTNtbk/V=0
	Notebook LaTeX2PICTNtbk, text=theLaTeX
	SaveNotebook/O/S=6/P=LaTeX2PICT LaTeX2PICTNtbk as theTeXFile

	// set the path where it all happened	
	theTempFile = theTempFolderU + theFileName
	theTempFolderU = RemoveEnding(theTempFolderU)

	// run the compiler and get the picture
	variable rtn
	string theSys, theCmd
	theSys = IgorInfo(2)	
	StrSwitch	(theSys)
		case "Windows":
			// SOMEONE MUST WRITE THIS SECTION
			theCmd = generateWinCmd(theTempFolderU, theTempFile)
			iname = ""
			break
		case "Macintosh":
			theCmd = generateMacCmd(theTempFolderU, theTempFile)
			ExecuteScriptText/UNQ/Z theCmd
			string/G COMPILEREPORT = S_value
			if (V_flag==0)
				LoadPICT/Q/O/P=LaTeX2PICT thePDFFile, $iname
			else
				iname = ""
				switch(prterr)
					case 0:
						break
					case 1:
						print "Error on compilation. See COMPILEREPORT string in root folder and log at " + theTempFolderU
						break
					case 2:
						print S_value
						break
				endswitch
			endif
			break
	endswitch
	
	return iname
end

// generate the macintosh command string
Static Function/S generateMacCmd(theTFU, theTF)
	string theTFU, theTF

	string theCmd
	sprintf theCmd, "/Library/TeX/texbin/pdflatex -output-directory='%s' '%s'", theTFU, theTF
	sprintf theCmd, "do shell script \"%s\"", theCmd
	return theCmd
end

Static Function/S generateWinCmd(theTFU, theTF)
	string theTFU, theTF

	string theCmd = ""	
	return theCmd
end